==> find_external_links-8.x-1.0.tar.gz: find_external_links/src/Form/ConfigurationForm.php <==
<?php

namespace Drupal\find_external_links\Form;

use Drupal;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form constructor for find_external_links_input_form.
 */
class ConfigurationForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'find_external_links_input_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $content_types = node_type_get_names();
    $form['description'] = [
      '#type' => 'markup',
      '#markup' => $this->t('<p><strong>Please select content type you want to find for external links.</strong></p>'),
    ];
    foreach ($content_types as $key => $value) {
      $form[$key] = [
        '#type' => 'checkbox',
        '#title' => $value,
        '#options' => $value,
      ];
    }
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Find External Links'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Validate submitted form data.
    $form_values = $form_state->getValues();
    $types = node_type_get_names();

    foreach ($form_values as $key => $values) {
      if (array_key_exists($key, $types)) {
        if ($values == 1) {
          $content_types[] = $key;
        }
      }
    }
    if (empty($content_types)) {
      $form_state->setErrorByName('select_content_types', $this->t('Seems you have not selected any content type. Please select atleast one content type you want to update first.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Handle submitted form data.
    $selected_content_types = [];
    $form_values = $form_state->getValues();
    $types = node_type_get_names();
    foreach ($form_values as $key => $values) {
      if (array_key_exists($key, $types)) {
        if ($values == 1) {
          $selected_content_types[] = $key;
        }
      }
    }

    $query = Drupal::database();
    $query->delete('find_external_links')
          ->execute();


    $node_ids = $this->findExternalLinksSelectedNid($selected_content_types);

    if (!count($node_ids)) {
      drupal_set_message($this->t("Seems You don't currently have any nodes with the selected content types."));
    }
    // Execute the function named update_external_links_batch_start.
    else {
      $batch = $this->findExternalLinksBatchStart($node_ids);
      batch_set($batch);
    }
  }

  /**
   * Utility function- simply querie and loads all nid of selected content type.
   */
  public function findExternalLinksSelectedNid(array $content_types_name) {
    $query = db_select('node', 'n');
    $query->innerjoin('node__body', 'b', 'n.nid = b.entity_id');
    $query->fields('n', ['nid'])->condition('b.body_value', '', '<>')->condition('n.type', $content_types_name, 'IN')->orderBy('n.nid', 'ASC');
    $nid = $query->execute()->fetchCol();
    return $nid;
  }

  /**
   * Batch process start function.
   */
  public function findExternalLinksBatchStart($node_ids) {
    $num_operations = count($node_ids);

    if ($num_operations > 0) {
      $operations = [];
      for ($i = 0; $i < $num_operations; $i++) {
        $nid = $node_ids[$i];
        $operations[] = [
          'find_external_links_process_1',
          [
            $nid,
            t('(Operation @operation)', ['@operation' => $num_operations]),
          ],
        ];
      }
    }

    $batch = [
      'operations' => $operations,
      'finished' => 'find_external_links_finished',
      'title' => $this->t('Processing External Links'),
      'init_message' => $this->t('Find external links process is starting.'),
      'progress_message' => $this->t('Processed @current out of @total.'),
      'error_message' => $this->t('Find External Link has encountered an error.'),
      'file' => drupal_get_path('module', 'find_external_links') . '/batch.inc',
    ];
    return $batch;
  }

}

==> find_external_links-8.x-1.1.tar.gz: find_external_links/src/Form/ConfigurationForm.php <==
<?php

namespace Drupal\find_external_links\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form constructor for find_external_links_input_form.
 */
class ConfigurationForm extends FormBase {
   /**
   * @var \Drupal\Core\Database\Connection
   */
  private $connection;

  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'find_external_links_input_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $content_types = node_type_get_names();
    $form['description'] = [
      '#type' => 'markup',
      '#markup' => $this->t('<p><strong>Please select content type you want to find for external links.</strong></p>'),
    ];
    foreach ($content_types as $key => $value) {
      $form[$key] = [
        '#type' => 'checkbox',
        '#title' => $value,
        '#options' => $value,
      ];
    }
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Find External Links'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Validate submitted form data.
    $form_values = $form_state->getValues();
    $types = node_type_get_names();

    foreach ($form_values as $key => $values) {
      if (array_key_exists($key, $types)) {
        if ($values == 1) {
          $content_types[] = $key;
        }
      }
    }
    if (empty($content_types)) {
      $form_state->setErrorByName('select_content_types', $this->t('Seems you have not selected any content type. Please select atleast one content type you want to update first.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Handle submitted form data.
    $selected_content_types = [];
    $form_values = $form_state->getValues();
    $types = node_type_get_names();
    foreach ($form_values as $key => $values) {
      if (array_key_exists($key, $types)) {
        if ($values == 1) {
          $selected_content_types[] = $key;
        }
      }
    }

    $this->connection->delete('find_external_links')
      ->execute();

    $node_ids = $this->findExternalLinksSelectedNid($selected_content_types);

    if (!count($node_ids)) {
      drupal_set_message($this->t("Seems You don't currently have any nodes with the selected content types."));
    }
    // Execute the function named update_external_links_batch_start.
    else {
      $batch = $this->findExternalLinksBatchStart($node_ids);
      batch_set($batch);
    }
  }

  /**
   * Utility function- simply querie and loads all nid of selected content type.
   */
  public function findExternalLinksSelectedNid(array $content_types_name) {
    $query = db_select('node', 'n');
    $query->innerjoin('node__body', 'b', 'n.nid = b.entity_id');
    $query->fields('n', ['nid'])->condition('b.body_value', '', '<>')->condition('n.type', $content_types_name, 'IN')->orderBy('n.nid', 'ASC');
    $nid = $query->execute()->fetchCol();
    return $nid;
  }

  /**
   * Batch process start function.
   */
  public function findExternalLinksBatchStart($node_ids) {
    $num_operations = count($node_ids);

    if ($num_operations > 0) {
      $operations = [];
      for ($i = 0; $i < $num_operations; $i++) {
        $nid = $node_ids[$i];
        $operations[] = [
          'find_external_links_process_1',
          [
            $nid,
            $this->t('(Operation @operation)', ['@operation' => $num_operations]),
          ],
        ];
      }
    }

    $batch = [
      'operations' => $operations,
      'finished' => 'find_external_links_finished',
      'title' => $this->t('Processing External Links'),
      'init_message' => $this->t('Find external links process is starting.'),
      'progress_message' => $this->t('Processed @current out of @total.'),
      'error_message' => $this->t('Find External Link has encountered an error.'),
      'file' => drupal_get_path('module', 'find_external_links') . '/batch.inc',
    ];
    return $batch;
  }

}
